@@ -183,7 +183,7 @@ This main function repeatedly calls the polygon api every 1 seconds for 10 hours
 Arguments:
     - currency_pairs: Nested list with all the information about each currency pair
 """
-def mainFunc(currency_pairs, time):
+def mainFunc(currency_pairs, duration):
     # The api key given by the professor
     key = "beBybSi8daPgsTp5yx5cHtHpYcrjp5Jq"
 
@@ -202,7 +202,7 @@ def mainFunc(currency_pairs, time):
     client = RESTClient(key)
 
     # Loop that runs until the total duration of the program hits 10 hours (= 36000 seconds).
-    while count < time:
+    while count < duration:
 
         # Make a check to see if 6 minutes has been reached or not
         if agg_count == 360:
